==> lightdash_client_python-0.1286.0-py3-none-any.whl: lightdash_client/models/api_calculate_total_response.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.api_calculate_total_response_status import ApiCalculateTotalResponseStatus

if TYPE_CHECKING:
    from ..models.record_string_number import RecordStringNumber


T = TypeVar("T", bound="ApiCalculateTotalResponse")


@_attrs_define
class ApiCalculateTotalResponse:
    """
    Attributes:
        results (RecordStringNumber): Construct a type with a set of properties K of type T
        status (ApiCalculateTotalResponseStatus):
    """

    results: "RecordStringNumber"
    status: ApiCalculateTotalResponseStatus
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        results = self.results.to_dict()

        status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "results": results,
                "status": status,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.record_string_number import RecordStringNumber

        d = src_dict.copy()
        results = RecordStringNumber.from_dict(d.pop("results"))

        status = ApiCalculateTotalResponseStatus(d.pop("status"))

        api_calculate_total_response = cls(
            results=results,
            status=status,
        )

        api_calculate_total_response.additional_properties = d
        return api_calculate_total_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> lightdash_client_python-0.1403.1-py3-none-any.whl: lightdash_client/models/api_calculate_total_response.py <==
from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.api_calculate_total_response_status import ApiCalculateTotalResponseStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.record_string_number import RecordStringNumber


T = TypeVar("T", bound="ApiCalculateTotalResponse")


@_attrs_define
class ApiCalculateTotalResponse:
    """
    Attributes:
        results (RecordStringNumber): Construct a type with a set of properties K of type T
        status (ApiCalculateTotalResponseStatus):
    """

    results: "RecordStringNumber"
    status: ApiCalculateTotalResponseStatus
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.record_string_number import RecordStringNumber

        results = self.results.to_dict()

        status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "results": results,
                "status": status,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.record_string_number import RecordStringNumber

        d = src_dict.copy()
        results = RecordStringNumber.from_dict(d.pop("results"))

        status = ApiCalculateTotalResponseStatus(d.pop("status"))

        api_calculate_total_response = cls(
            results=results,
            status=status,
        )

        api_calculate_total_response.additional_properties = d
        return api_calculate_total_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
